@@ -1,26 +1,8 @@
-/***************************************************************************
-
-    C++ Implementation: keduvocdeclension
-
-    -----------------------------------------------------------------------
-
-    begin         : Do Sep 20 2007
-
-    copyright     : (C) 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
-    -----------------------------------------------------------------------
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
+/*
+ * C++ Implementation: keduvocdeclension
+ * SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "keduvocdeclension.h"
 
 #include "kvtml2defs.h"
